@@ -18,10 +18,12 @@ def test_filter_by_text():
     bag = Bag('bag0')
     bag = store.get(bag)
 
-    bags_tiddlers = bag.list_tiddlers()
+    bags_tiddlers = list(store.list_bag_tiddlers(bag))
     assert len(bags_tiddlers) == 10
 
-    found_tiddlers = list(control.filter_tiddlers_from_bag(bag, 'select=text:tiddler 0'))
+    found_tiddlers = list(control._filter_tiddlers_from_bag(
+        bag, 'select=text:tiddler 0',
+        environ={'tiddlyweb.store': store}))
     assert len(found_tiddlers) == 1
     assert found_tiddlers[0].title == 'tiddler0'
 
@@ -29,10 +31,12 @@ def test_filter_by_text_string():
     bag = Bag('bag0')
     bag = store.get(bag)
 
-    bags_tiddlers = bag.list_tiddlers()
+    bags_tiddlers = list(store.list_bag_tiddlers(bag))
     assert len(bags_tiddlers) == 10
 
-    found_tiddlers = list(control.filter_tiddlers_from_bag(bag, 'select=text:tiddler 0'))
+    found_tiddlers = list(control._filter_tiddlers_from_bag(
+        bag, 'select=text:tiddler 0',
+        environ={'tiddlyweb.store': store}))
     assert len(found_tiddlers) == 1
     assert found_tiddlers[0].title == 'tiddler0'
 
@@ -40,8 +44,10 @@ def test_filter_by_text_string_negate():
     bag = Bag('bag0')
     bag = store.get(bag)
 
-    bags_tiddlers = bag.list_tiddlers()
+    bags_tiddlers = list(store.list_bag_tiddlers(bag))
     assert len(bags_tiddlers) == 10
 
-    found_tiddlers = list(control.filter_tiddlers_from_bag(bag, 'select=text:!tiddler 0'))
+    found_tiddlers = list(control._filter_tiddlers_from_bag(bag,
+        'select=text:!tiddler 0',
+        environ={'tiddlyweb.store': store}))
     assert len(found_tiddlers) == 9
