@@ -3,13 +3,11 @@ Test that GETting a bag can list the tiddlers.
 """
 
 
-from wsgi_intercept import httplib2_intercept
-import wsgi_intercept
 import httplib2
 import urllib
 import simplejson
 
-from fixtures import muchdata, reset_textstore, _teststore
+from fixtures import muchdata, reset_textstore, _teststore, initialize_app
 
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.stores import StorageInterface
@@ -23,14 +21,7 @@ policy_dict = dict(
         owner=u'chris')
 
 def setup_module(module):
-    from tiddlyweb.web import serve
-    # we have to have a function that returns the callable,
-    # Selector just _is_ the callable
-    def app_fn():
-        return serve.load_app()
-    #wsgi_intercept.debuglevel = 1
-    httplib2_intercept.install()
-    wsgi_intercept.add_wsgi_intercept('our_test_domain', 8001, app_fn)
+    initialize_app()
 
     reset_textstore()
     module.store = _teststore()
