@@ -6,6 +6,10 @@ import Cookie
 import urllib
 import time
 from datetime import datetime
+try:
+    from email.utils import parsedate
+except ImportError: #  Python < 2.5
+    from email.Utils import parsedate
 
 from tiddlyweb.web.http import HTTP415
 from tiddlyweb.util import sha
@@ -88,9 +92,7 @@ def datetime_from_http_date(http_datestring):
     """
     if ';' in http_datestring:
         http_datestring = http_datestring.split(';', 1)[0].rstrip().lstrip()
-    http_datetime = datetime(*(time.strptime(http_datestring,
-        '%a, %d %b %Y %H:%M:%S GMT')[0:6]))
-    return http_datetime
+    return datetime(*parsedate(http_datestring)[:6])
 
 
 def make_cookie(name, value, mac_key=None, path=None,
@@ -172,12 +174,13 @@ def html_encode(text):
 
 def escape_attribute_value(text):
     """
-    escape double quotes in attribute values
+    escape common character entities, incuding double quotes
+    in attribute values
 
     This assumes values are enclosed in double quotes (key="value").
     """
     try:
-        return text.replace('"', '&quot;')
+        return html_encode(text).replace('"', '&quot;')
     except AttributeError:  # value might be None
         return text
 
